@@ -11,7 +11,7 @@ import threading
 import unicodedata
 
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 
 logger = logging.getLogger(__name__)
@@ -41,8 +41,8 @@ def _download(url, destination, sha1):
     dirname = os.path.dirname(destination)
 
     # Can't use NamedTemporaryFile because it would try to delete afterwards
-    fd, tmp = tempfile.mkstemp(dir=dirname)
-    os.close(fd)
+    # Doesn't use mkstemp because permissions are too strict
+    tmp = tempfile.mktemp(dir=dirname)
     try:
         with open(tmp, 'wb') as fp:
             with requests.get(url, stream=True) as resp:
@@ -62,8 +62,7 @@ def _download(url, destination, sha1):
         with open(tmp, 'rb') as fp:
             magic = fp.read(2)
         if magic == b'\x1F\x8B':
-            fd, tmp2 = tempfile.mkstemp(dir=dirname)
-            os.close(fd)
+            tmp2 = tempfile.mktemp(dir=dirname)
             try:
                 with open(tmp2, 'wb') as dest:
                     with gzip.open(tmp) as src:
