@@ -1,9 +1,12 @@
 import argparse
+import logging
 
 from . import __version__ as VERSION, GeoData
 
 
 def main():
+    logging.basicConfig(level=logging.INFO)
+
     parser = argparse.ArgumentParser(
         description="Download the data",
     )
